# Themer
A WIP theme engine for macOS, written in Python.

# Installation
## Using Pip
```bash
  $ pip install pythemer
```
## Manual
```bash
  $ git clone https://github.com/pythemer/themer
  $ cd themer
  $ python setup.py install
```
# Usage
```bash
$ themer
```